@@ -252,6 +252,8 @@ def get_venue(venueId):
 		return response[u'response'][u'venue']
 
 
+# TODO: make this entire file OO, and this an actual attribute of it
+checkin_hooks = list()
 def checkin(venue, ll, shout=""):
 	"""
 	Checks in the user at venue with lat/lng ll
@@ -263,9 +265,19 @@ def checkin(venue, ll, shout=""):
 	print "Checking in with broadcast = " + broadcast
 
 	response = foursquare_post("/checkins/add", {'shout': shout, 'venueId': venue[u'id'], 'broadcast': broadcast, 'll': ll})
+
+	# This is, without doubt, the nastiest hack I've ever done!
+	print len(checkin_hooks)
+	for hook in checkin_hooks:
+		hook()
+	
 	return response
 
 
+def add_checkin_hook(hook):
+	checkin_hooks.append(hook)
+
+
 def get_last_ll():
 	"""
 	Returns the ll of the user's last checkin
