@@ -27,10 +27,10 @@ from venues import NewVenueWindow, VenueListWindow
 from foursquare import Cache
 from locationProviders import LocationProviderSelector, LocationProvider
 from threads import VenueProviderThread, UserUpdaterThread, ImageCacheThread, UpdateSelf, VenueSearchThread
-from custom_widgets import SignalEmittingValueButton, CategorySelector, UberSquareWindow, Title
+from custom_widgets import SignalEmittingValueButton, CategorySelector, UberSquareWindow, Title, Ruler
 from users import UserListWindow
 from about import AboutDialog
-
+from datetime import datetime
 
 class Profile(QWidget):
     def __init__(self, parent=None):
@@ -39,6 +39,7 @@ class Profile(QWidget):
         self.photo_label = QLabel()
 
         self.textLabel = QLabel()
+        self.textLabel.setWordWrap(True)
         self.__updateInfo(True)
 
         name = ""
@@ -47,18 +48,16 @@ class Profile(QWidget):
         if u'lastName' in self.user:
             name += self.user[u'lastName']
 
-        #self.nameTitle = Title(name)
-        self.nameTitle = QLabel("<b>" + name + "</b>")
+        self.nameTitle = Title(name)
 
         profileLayout = QGridLayout()
         self.setLayout(profileLayout)
         profileLayout.addWidget(self.photo_label, 0, 0, 2, 1)
-        profileLayout.addWidget(self.nameTitle, 0, 1, 1, 2)
-        profileLayout.addWidget(self.textLabel, 1, 1, 1, 2)
-        profileLayout.setSpacing(2)
-        profileLayout.setContentsMargins(0, 0, 0, 0)
-
-        #profileLayout.addWidget(QLabel("current user location"), 1, 0, 1, 3)
+        profileLayout.addWidget(self.nameTitle, 0, 1)
+        profileLayout.addWidget(self.textLabel, 1, 1)
+        profileLayout.setColumnStretch(1, 5)
+        profileLayout.setSpacing(5)
+        profileLayout.setContentsMargins(11, 11, 11, 11)
 
         clicked = Signal()
         self.connect(self, SIGNAL("clicked()"), self.__clicked)
@@ -66,6 +65,8 @@ class Profile(QWidget):
         selfUpdated = Signal()
         self.connect(self, SIGNAL("selfUpdated()"), self.__updateInfo)
 
+        foursquare.add_checkin_hook(self.checkin)
+
     def __clicked(self):
         t = UpdateSelf(self)
         t.start()
@@ -74,16 +75,25 @@ class Profile(QWidget):
     def mousePressEvent(self, event):
         self.clicked.emit()
 
+    def checkin(self):
+        t = UpdateSelf(self)
+        t.start()
+
     def __updateInfo(self, initial=False):
         if not initial:
             QMaemo5InformationBox.information(self, "Stats updated!", 1500)
             self.user = foursquare.get_user("self", foursquare.CacheOrGet)[u'user']
 
-        badges = str(self.user[u'badges'][u'count']) + " badges"
-        mayorships = str(self.user[u'mayorships'][u'count']) + " mayorships"
-        checkins = str(self.user[u'checkins'][u'count']) + " checkins"
+        badges = "<b>" + str(self.user[u'badges'][u'count']) + "</b> badges"
+        mayorships = "<b>" + str(self.user[u'mayorships'][u'count']) + "</b> mayorships"
+        checkins = "<b>" + str(self.user[u'checkins'][u'count']) + "</b> checkins"
 
-        text = badges + "<br>" + mayorships + "<br>" + checkins
+        location = self.user[u'checkins'][u'items'][0][u'venue'][u'name']
+        lastSeen = self.user[u'checkins'][u'items'][0][u'createdAt']
+        lastSeen = datetime.fromtimestamp(lastSeen).strftime("%Y-%m-%d %X")
+        location = "Last seen @" +  location # + "</b>, at <i>" + lastSeen + "</i>"
+
+        text = location + "<br>" + badges + " | " + mayorships + " | " + checkins
         self.textLabel.setText(text)
 
         self.photo = QImage(foursquare.image(self.user[u'photo']))
@@ -137,35 +147,33 @@ class MainWindow(UberSquareWindow):
         logout_button = QPushButton("Forget credentials")
         self.connect(logout_button, SIGNAL("clicked()"), self.logout_pushed)
 
-        new_venue_button = QPushButton("Add")
+        new_venue_button = QPushButton("Create Venue")
         self.connect(new_venue_button, SIGNAL("clicked()"), self.new_venue_pushed)
 
         leaderboard_button = QPushButton("Leaderboard")
         self.connect(leaderboard_button, SIGNAL("clicked()"), self.leaderboard_button_pushed)
 
-        settings_button = QPushButton("Settings")
+        settings_button = QPushButton("Sharing")
         self.connect(settings_button, SIGNAL("clicked()"), self.settings_button_pushed)
 
         row = 0
-        gridLayout.addWidget(Profile(), row, 0, 3, 1)
-        gridLayout.addWidget(QLabel("<b>Venues</b>"), row, 1, Qt.AlignHCenter)
-        row += 1
-        gridLayout.addWidget(previous_venues_button, row, 1)
+        gridLayout.addWidget(Profile(), row, 0, 1, 2)
         row += 1
+        gridLayout.addWidget(previous_venues_button, row, 0)
         gridLayout.addWidget(todo_venues_button, row, 1)
         row += 1
-        gridLayout.addWidget(leaderboard_button, row, 0)
+        gridLayout.addWidget(new_venue_button, row, 0)
         gridLayout.addWidget(search_venues_button, row, 1)
         row += 1
-        gridLayout.addWidget(self.location_button, row, 0)
-        gridLayout.addWidget(new_venue_button, row, 1)
+        gridLayout.addWidget(leaderboard_button, row, 0)
         row += 1
         gridLayout.addWidget(QLabel("<b>Settings</b>"), row, 0, 1, 2, Qt.AlignHCenter)
         row += 1
-        gridLayout.addWidget(images_button, row, 0)
+        gridLayout.addWidget(self.location_button, row, 0)
         gridLayout.addWidget(settings_button, row, 1)
         row += 1
-        gridLayout.addWidget(logout_button, row, 0)
+        gridLayout.addWidget(images_button, row, 0)
+        gridLayout.addWidget(logout_button, row, 1)
 
         self.setupMenu()
         self._venues = None
@@ -197,13 +205,13 @@ class MainWindow(UberSquareWindow):
         about.setText("About")
         self.connect(about, SIGNAL("triggered()"), self.__showAbout)
 
-        settings = QAction(self)
-        settings.setText("Settings")
+        #settings = QAction(self)
+        #settings.setText("Settings")
 
         menubar = QMenuBar(self)
         self.setMenuBar(menubar)
 
-        menubar.addAction(settings)
+        #menubar.addAction(settings)
         menubar.addAction(about)
 
     def __showAbout(self):
@@ -312,6 +320,11 @@ class SettingsDialog(UberSquareWindow):
         layout = QGridLayout(self.cw)
         layout.setContentsMargins(22, 22, 22, 22)
 
+        notice = "You'll need to link your facebook/twitter account from the foursquare website for these setting to have any effect."
+        notice += "  The foursquare API does not offer any means for applications to do this."
+        label = QLabel(notice)
+        label.setWordWrap(True)
+
         self.tw = QCheckBox("Post to Twitter")
         self.fb = QCheckBox("Post to Facebook")
 
@@ -324,10 +337,11 @@ class SettingsDialog(UberSquareWindow):
         self.saveButton = QPushButton("Save")
         self.connect(self.saveButton, SIGNAL("clicked()"), self.save)
 
-        layout.addWidget(self.tw, 0, 0)
-        layout.addWidget(self.fb, 1, 0)
-        layout.addWidget(self.saveButton, 2, 0)
-        layout.setRowStretch(3, 3)
+        layout.addWidget(label, 0, 0)
+        layout.addWidget(self.tw, 1, 0)
+        layout.addWidget(self.fb, 2, 0)
+        layout.addWidget(self.saveButton, 3, 0)
+        layout.setRowStretch(4, 3)
 
     def save(self):
         broadcast = "public"
